@@ -1,6 +1,11 @@
 from typing import Union
 
 
+class UnsupportedMediaType(Exception):
+    """Unable to parse the request (based on the Content-Type)"""
+    pass
+
+
 class RequestValidationError(Exception):
     def __init__(self, errors: Union[list, dict], code=None, params=None):
         super().__init__(errors, code, params)
