@@ -1,51 +1,23 @@
 import copy
 import json
-from collections import OrderedDict
 from typing import Union
 
-import msgpack
-from django.core.exceptions import ValidationError, NON_FIELD_ERRORS
-from django.forms import MediaDefiningClass, Field
+from django.core.exceptions import NON_FIELD_ERRORS, ValidationError
+from django.forms.forms import DeclarativeFieldsMetaclass
 from django.utils.translation import gettext as _
 
-from .exceptions import RequestValidationError
+from .exceptions import RequestValidationError, UnsupportedMediaType
+
+try:
+    import msgpack
+    is_msgpack_installed = True
+except ImportError:
+    is_msgpack_installed = False
 
 
-class DeclarativeFieldsMetaclass(MediaDefiningClass):
-    """Collect Fields declared on the base classes."""
-
-    def __new__(mcs, name, bases, attrs):
-        # Collect fields from current class.
-        current_fields = []
-        for key, value in list(attrs.items()):
-            if isinstance(value, Field):
-                current_fields.append((key, value))
-                attrs.pop(key)
-        attrs['declared_fields'] = OrderedDict(current_fields)
-
-        new_class = super(DeclarativeFieldsMetaclass, mcs).__new__(mcs, name, bases, attrs)
-
-        # Walk through the MRO.
-        declared_fields = OrderedDict()
-        for base in reversed(new_class.__mro__):
-            # Collect fields from base class.
-            if hasattr(base, 'declared_fields'):
-                declared_fields.update(base.declared_fields)
-
-            # Field shadowing.
-            for attr, value in base.__dict__.items():
-                if value is None and attr in declared_fields:
-                    declared_fields.pop(attr)
-
-        new_class.base_fields = declared_fields
-        new_class.declared_fields = declared_fields
-
-        return new_class
-
-    @classmethod
-    def __prepare__(metacls, name, bases, **kwds):
-        # Remember the order in which form fields are defined.
-        return OrderedDict()
+parsers_by_content_type = {'application/json': json.loads}
+if is_msgpack_installed:
+    parsers_by_content_type['application/x-msgpack'] = msgpack.loads
 
 
 class BaseForm(object):
@@ -88,12 +60,12 @@ class BaseForm(object):
         if not request.body:
             return cls(None)
 
-        if request.META.get('CONTENT_TYPE') and 'application/json' in request.META.get('CONTENT_TYPE'):
-            data = json.loads(request.body)
-        elif request.META.get('CONTENT_TYPE') and 'application/x-msgpack' in request.META.get('CONTENT_TYPE'):
-            data = msgpack.loads(request.body)
+        content_type = request.META.get('CONTENT_TYPE', '')
+        parser = parsers_by_content_type.get(content_type)
+        if parser:
+            data = parser(request.body)
         else:
-            raise RuntimeError("Unable to parse request!")
+            raise UnsupportedMediaType
 
         return cls(data)
 
